#
# spec file for package brp-check-suse
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           brp-check-suse
AutoReqProv:    off
Summary:        Build root policy check scripts
# we need the full perl because of XML Parsing and utf-8
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
Requires:       perl
Version:        84.87+git20230324.8680ce4
Release:        1.6
URL:            https://github.com/openSUSE/brp-check-suse
BuildRequires:  gcc-c++
#
# Note: don't rebuild this manually. Instead submit your patches
# for inclusion in the git repo at https://github.com/openSUSE/brp-check-suse
#
Source0:        %{name}-%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%global provfind sh -c "grep -v 'brp-desktop.data' | %__find_provides"
%global __find_provides %provfind

%description
This package contains all suse scripts called in the
build root checking or in parts implementing SUSE policies.

%prep
%setup -q

%build
make -C prg-brp-symlink

%install
install -D -m 755 prg-brp-symlink/brp-symlink $RPM_BUILD_ROOT/%_bindir/brp-symlink.prg
install -d $RPM_BUILD_ROOT/usr/lib/rpm/brp-suse.d
mv brp*data $RPM_BUILD_ROOT/usr/lib/rpm/
cp -a brp-* $RPM_BUILD_ROOT/usr/lib/rpm/brp-suse.d

%check
make -C prg-brp-symlink check

%files
%defattr(-, root, root)
%license COPYING
/usr/lib/rpm/*
%_bindir/brp-symlink.prg

%changelog
* Fri Mar 24 2023 dmueller@suse.com
- Update to version 84.87+git20230324.8680ce4:
  * Remove __patchable_function_entries from .a objects
* Tue Nov 15 2022 Dirk Müller <dmueller@suse.com>
- Update to version 84.87+git20221115.2f7add6:
  * fallback to the libkcapi fipscheck
  * Remove legacy checks that are part of rpmlint 2.x.
  * brp-25-symlink: don't fail if the symlink target starts with a dash
  * Revert "Let symlinks from /lib/modules to /usr/src be absolute"
  * Fix /etc/alternatives being white listed
* Mon Sep 19 2022 Dirk Müller <dmueller@suse.com>
- use https:// for urls
* Tue Nov 16 2021 coolo@suse.com
- Update to version 84.87+git20211116.6c5fe09:
  * brp-25-symlink: don't fail if the symlink target starts with a dash
  * Revert "Let symlinks from /lib/modules to /usr/src be absolute"
* Tue Jul  6 2021 coolo@suse.com
- Update to version 84.87+git20210706.41c04c1:
  * Fix /etc/alternatives being white listed
* Tue Jun 22 2021 coolo@suse.com
- Update to version 84.87+git20210622.18841ca:
  * Extend symlinks in buildroot (and test them)
  * Move the exception handling of absolute links to C++
  * Revert "brp-25-symlink: Follow deeper symlinks to avoid false positives"
* Mon Jun  7 2021 lnussel@suse.de
- Update to version 84.87+git20210607.252083e:
  * Let symlinks from /lib/modules to /usr/src be absolute (boo#1186710)
* Mon May 17 2021 ro@suse.de
- Update to version 84.87+git20210517.7005a76:
  * support cross arch builds
  * Makefile only set CXXFLAGS and CXX if not set in env yet
  * brp-25-symlink: Follow deeper symlinks to avoid false positives
* Tue Apr 20 2021 ro@suse.de
- Update to version 84.87+git20210420.a4765d7:
  * rename brp-50-fipscheck to brp-50-generate-fips-hmac
* Mon Apr 19 2021 ro@suse.de
- Update to version 84.87+git20210419.bf6495b:
  * add brp-50-fipscheck for bsc#1184555
* Fri Jan 15 2021 coolo@suse.com
- Update to version 84.87+git20201203.5008eba:
  * brp-25-symlink: Detect if a link points inside the build root
  * brp-25-symlink: Remove unused $link part of the case statement
  * brp-25-symlink: Print all errors before exiting
  * Makefile: enable -O2, use standard variables and clean up
  * simplify split_paths using std::getline
* Tue Dec  1 2020 coolo@suse.com
- Update to version 84.87+git20201201.9bbfade:
  * skip . in links
* Tue Nov  3 2020 coolo@suse.com
- Update to version 84.87+git20201103.f6f1d35:
  * Fix error handling of brp-25-symlink
* Thu Sep 10 2020 coolo@suse.com
- Update to version 84.87+git20200910.754804a:
  * Make prg-brp-symlink compile on SLE15 (#34 and #35)
* Mon Aug 17 2020 ro@suse.de
- Update to version 84.87+git20200817.346e853:
  * added NO_BRP_PERMISSIONS and NO_BRP_ROOTFS (bug#968153)
* Fri Jul 31 2020 coolo@suse.com
- Update to version 84.87+git20200731.3af0c0a:
  * Make links *to* /etc/aternatives absolute links (#33)
  * Sort input file list (#32)
* Sun May 10 2020 coolo@suse.com
- Update to version 84.87+git20200510.8ff16cf:
  * Avoid relinking links to mounted kernel filesystems
  * Make all symlinks relative (bsc#1166667) (#31)
  * Get rid of the unmaintained and buggy desktop file check (#14)
* Sat Feb 15 2020 ro@suse.com
- Update to version 84.87+git20200215.db1636b:
  * refactor brp-15-strip-debug to not use /dev/fd/62
  * Also strip lto data from .o files (boo#1146634)
* Thu Oct 31 2019 ro@suse.de
- fix specfile to account for removed brp-65-lib64-linux
* Wed Oct 16 2019 ro@suse.com
- Update to version 84.87+git20191016.914fe67:
  * add Teaching and X-KDE-Teaching to Education (#27)
  * Remove brp-65-lib64-linux
  * Remove brp-35-rpath.
  * Remove brp-55-boot-scripts.
* Wed Aug  7 2019 mliska@suse.cz
- Update to version 84.87+git20190807.d5563f2:
  * Strip .gnu.debuglto_* and __gnu_lto_v1 in archives.
* Mon Aug  5 2019 Benjamin Greiner <code@bnavigator.de>
- Update to version 84.87+git20190801.8862c43
  * remove python 2.5 check (#19)
  * remove legacy brp-60-hook check (#20)
- rerequest changes from git20190729.e01ed36
* Mon Jul 29 2019 coolo@suse.com
- Update to version 84.87+git20190729.e01ed36:
  * make desktop category error message more meaningful (#17)
  * redefine Science and Education to comply with guidelines (#18)
* Mon Jul  8 2019 mliska@suse.cz
- Update to version 84.87+git20190702.bac0cab:
  * Add NO_BRP_AR as a way how to skip ar.
- Remove 0001-Remove-brp-75-ar-for-now.patch.
* Tue Jun 18 2019 Martin Liška <mliska@suse.cz>
- Add 0001-Remove-brp-75-ar-for-now.patch in order to temporarily
  disable the check.
* Tue Apr 23 2019 Martin Liška <mliska@suse.cz>
- Update to version 84.87+git20190423.d0bda31:
  * Strip LTO bytecode from static libraries.
  * Don't treat Adwaita specially
  - merges https://github.com/openSUSE/brp-check-suse/pull/11
  - drop adwaita from the exception list of icon themes,
    only hicolor is used as generic fallback
* Wed Feb 13 2019 opensuse-packaging@opensuse.org
- Update to version 84.87+git20190213.9c6487b:
  * Add brp-75-ar to normalize ar archives
* Tue Nov  6 2018 ro@suse.de
- Update to version 84.87+git20181106.224b37d:
  * brp-15-strip-debug: deal with libs where file outputs
    more text after "not stripped" (bsc#1114695)
* Sat Sep  8 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 84.87+git20180809.3335364:
  * Handle whitespace in symlinks correctly
- Use %%license
- Keep brp-65-lib64-linux also on aarch64
* Fri Jun  2 2017 dimstar@opensuse.org
- Update to version 84.87+git20170602.cec5415:
  * Add missing newline to Category error message
  * brp-25-symlink: do not relink /etc/os-release
* Tue Sep  6 2016 lnussel@suse.de
- Update to version 84.87+git20160906.bb0a7d0:
  * brp-25-symlink: handle properly symlinks to root directory
  * - do not fail over new DefaultLayout element
  * neededforbuild -> BuildRequires
  * properly create tarball
  * Hint to the desktop category rules. (#6)
* Wed Jan 13 2016 ro@suse.de
- update tarball to actually include last fixes, new version
  is 13.2+git20150521.971ea2f (bnc#781101)
- change neededforbuild to BuildRequires in output text in
  brp-25-symlink
- do not fail over new DefaultLayout element
- brp-25-symlink: handle properly symlinks to root directory
* Fri Apr 10 2015 ro@suse.de
- do not fail over new DefaultLayout element (from adrian)
- brp-25-symlink: handle properly symlinks to root directory
  (fix bnc#781101) (from sleep_walker)
* Mon Feb 16 2015 opensuse-packaging@opensuse.org
- Update to version 13.2+git20150217.031533d:
  + - Update applications.menu from desktop-data to accept new
    Categories (bnc#443364), remove PuzzleGame (now LogicGame)
    (thanks sbrabec)
* Mon Oct 20 2014 dmueller@suse.com
- Update to version 13.2+git20140829.9539e1d:
  + xdg_menu: use File::Find instead of calling out to find
  + brp-25-symlink: fix missing alternatives
  + brp-25-symlink: fix eating /./ in path
  + brp-25-symlink: massive rewrite to reduce number of calls
  + brp-40-rootfs: reduce number of calls
  + brp-60-hook: add some double quotes
  + brp-50-check-python: add some double quotes, remove commented code
  + Adwaita is a defined icon theme mandatory installed as dependency to GTK3.
* Wed Jul 30 2014 sleep_walker@suse.cz
- correct URL to github repo
* Sun Jul 27 2014 sleep_walker@suse.cz
- brp-25-symlink: add mising '/etc/alternatives' back to whitelist
* Sat Jul 26 2014 sleep_walker@suse.cz
- brp-25-symlink: fix eating /./ in path
* Fri Jul 25 2014 sleep_walker@suse.cz
- massive rewrite of brp-25-symlink to reduce number of calls our
  tests shown speedup from 8,5 mins to 1 min for kernel-default
  (year ago)
* Wed Jul 23 2014 sleep_walker@suse.cz
- All GTK apps are allowed to assume the presence of the
  Adwaita-icon-theme package; As a result of this, we now accept icons
  in icons/Adwaita on the whitelist (just as hicolor).
  patch by DimStar
* Wed Jul 23 2014 sleep_walker@suse.cz
- remove brp-20-check-la, it is broken and la files are mostly
  deleted anyway
- reduction of number of calls used by using more bashism, passing
  more regexp at once, use more double quotes
  brp-15-strip-debug
  brp-45-tcl
  brp-50-check-python
  brp-60-hook
* Wed Jul  2 2014 ro@suse.de
- do not ignore errors just because package has no init script
- allow .local scripts for aaa_base so we can ghost them there
- remove outdated echo line
* Mon Feb 24 2014 coolo@suse.com
- switch to _service fetching from github
- fix brp-symlinks to avoid errors on links to alternatives and
  remove check-broken-symlinks.diff
* Mon Nov 12 2012 coolo@suse.com
- document the need for full perl
* Sun Jul  1 2012 coolo@suse.com
- do not allow symlinks to point to itself (not existant as result)
* Tue Mar 13 2012 ro@suse.de
- integrate brp-check-xdg-menus.patch (and add to git)
- ignore empty elements in rpath
* Fri Mar  9 2012 dimstar@opensuse.org
- Add brp-check-xdg-menus.patch: Accept all icons specified in icon
  naming spec.
* Fri Dec  9 2011 coolo@suse.com
- let rpm call everything below /usr/lib/rpm/brp-suse.d and do no
  longer define a hard coded list of brp scripts
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Jul 11 2011 coolo@novell.com
- do no longer check for libraries in /usr (bnc#696004)
* Fri May 13 2011 lnussel@suse.de
- remove brp-pie, replaced with rpmlint check
* Thu Apr 28 2011 ro@suse.de
- try to make sure it really is a libtool file before taking any action
* Fri Mar  4 2011 cdenicolo@novell.com
- Artistic no longer found.
* Thu Jan 13 2011 ro@suse.de
- switch to git source
- integrate fix-mail patch
* Mon Jan 10 2011 ro@suse.de
- disable autoreqprov
* Mon Jan 10 2011 ro@suse.de
- really drop brp-check-bytecode-version
- integrate fix-mail patch into tarball
* Mon Jan 10 2011 mvyskocil@suse.cz
- fix bnc#465005 - drop brp-check-bytecode-version
* Wed Nov 10 2010 lnussel@suse.de
- remove %%suse_check
- add brp-permissions
* Mon Apr 12 2010 ro@suse.de
- update contained perl-XML-NamespaceSupport from 1.08 to 1.11
- update contained perl-XML-SAX from 0.12 to 0.96
* Sun Feb 14 2010 ro@suse.de
- block provides for private perl modules
* Thu Feb 11 2010 ro@suse.de
- replace mail address by http url in xdg_data check (bnc#510720)
* Thu Sep 17 2009 ro@suse.de
- brp-desktop: debugging showed the problem:
  "/usr/bin/find: Argument list too long"
  split the command to look below RPM_BUILD_ROOT first and
  search based from / only if the first one did not find anything
  this should even speed things up a bit
* Thu Sep 17 2009 ro@suse.de
- brp-desktop: print icon file for debugging
- debug output from find in failure case
* Thu Feb 26 2009 ro@suse.de
- brp-desktop: relax icon check: allow more directories
  (bnc#423717)
* Wed Jan 14 2009 coolo@suse.de
- brp-desktop: do not check for SuSE-translate anymore and leave that
  to rpmlint
* Wed Jan  7 2009 jblunck@suse.de
- brp-strip-debug: Fix "find: paths must precede expression" errors
* Tue Dec 16 2008 lnussel@suse.de
- remove dbus script, replaced by rpmlint check
* Thu Dec  4 2008 thomas@suse.de
- updated dbus whitelist for package sugar
* Thu Nov 20 2008 thomas@suse.de
- added cnetworkmanager.conf to dbus autostart and system service
  whitelist (bnc#446997)
- changed wording of messages in dbus-autostart script
* Tue Nov 11 2008 thomas@suse.de
- adjusted dbus whitelist for backup-manager dbus services
* Thu Oct 16 2008 thomas@suse.de
- added script to detect yet unknown dbus autostart system-service
  files, the set of known files can be updated using a whitelist
  (generated for all archs of 11.0)
* Wed Oct 15 2008 ro@suse.de
- Add more legal Categories to desktop-data-openSUSE and brp-check
  (bnc#430979)
* Wed Oct  8 2008 meissner@suse.de
- ntpdate is no longer a binary, but a shellscript
* Mon Oct  6 2008 jblunck@suse.de
- brp-strip-debug: don't strip debuginfo from static libraries, but
  compiler-generated local symbols
* Wed Sep 24 2008 adrian@suse.de
- adapt email address to new maintainer of desktop checks;)
* Thu Sep  4 2008 ro@suse.de
- rename to brp-check-suse
* Sun Aug 17 2008 ro@suse.de
- downgrade missing Required-Stop to warning
* Thu Aug 14 2008 ro@suse.de
- tweak brp-boot-scripts some more:
  - prefix every line with W: or E: accordingly
  - missing Should-Stop is a warning
  - present but empty FOO-Stop is an error if the matching
    FOO-Start is non-empty
* Wed Aug 13 2008 ro@suse.de
- applied fastjar patch to bytecode-check script
  (allow use of jar and fastjar additional to unzip)
* Mon Aug 11 2008 werner@suse.de
- Add brp-boot-scripts for checking init and boot scripts
* Fri Aug  1 2008 ro@suse.de
- removed syslog-ng from pie list (approved by meissner)
* Sun May 18 2008 ro@suse.de
- add X-SuSE-YaST to exclude list in System/More Programs
  as explained in bugzilla (bnc#382778)
* Wed Feb 13 2008 ro@suse.de
- updated brp-pie from bk: fix function for symlinks
* Fri Feb  8 2008 dmueller@suse.de
- remove references to previously removed checks (d'oh)
* Thu Feb  7 2008 dmueller@suse.de
- remove checks that are done by rpmlint already (bnc#356670)
* Thu Jan 31 2008 ro@suse.de
- remove brp-symlink, already in rpm.rpm
* Mon Jan 28 2008 ro@suse.de
- fix brp-check-bytecode for unzip case
* Mon Jan 28 2008 ro@suse.de
- brp-check-bytecode:
  - allow java-1.5 (file output: version 49.0)
  - try to use "jar" if "unzip" is not available
* Mon Dec 17 2007 ro@suse.de
- created package, version 1.0
